/*************************************************************************
 *
 * Definitions or Constants for main program
 *
 *************************************************************************/

#define     porta_dir    0b11101111    // "0" is output "1" is input
            // Pin RA0 analog input EdgeLeft (left line sensor)
            // Pin RA1 analog input EdgeCntLeft (center left line sensor)
            // Pin RA2 analog input EdgeCenter (center left line sensor)
            // Pin RA3 analog input EdgeCntRight (center right line sensor)
            // Pin RA4 No connection so make it an output
            // Pin RA5 analog input EdgeRight (right line sensor)
            // note PortA is only 6 bits!

#define     portc_dir    0b00000000    // "0" is output "1" is input
            // Pin RC0 direction = output -- Left Motor Direction
            // Pin RC1 direction = output -- Enable Left motor
            // Pin RC2 direction = output -- Enable Right motor
            // Pin RC5 direction = output -- Right Motor Direction

#define    all_inputs    0b11111111    // "0" is output "1" is input
#define    all_outputs   0b00000000    //  "0" is output "1" is input
#define    portd_dir     0b01100000    // "0" is output "1" is input

#define    led1    RD0    // output -- LED 1
#define    led2    RD1    // output -- LED 2
#define    led3    RD2    // output -- LED 3
#define    led4    RD3    // output -- LED 4
#define    led5    RD4    // output -- LED 5
#define    LeftIR  !RD5   // input -- Left IR
#define    RightIR !RD6   // input -- Right IR
            // Note that the IR detectors output low when an object
            // is detected and the LEDS require a low to turn them on,
            // so the not "!" of the pin is used in the define to
            // maintain positive logic

#define    LmotorForw    RC0    // pin_c0  -- Left motor forward
#define    enableLmotor  RC1    // pin_c1  -- Enable Left motor
#define    enableRmotor  RC2    // pin_c2  -- Enable Right motor
#define    RmotorForw    RC5    // pin_c5  -- Right motor forward

// ADC channels accessed by setting the channel select bit of ADCON0
// CHS2, CHS1 and CHS0  are bits 5, 4 and 3 of ADCON0
// bits 7,6 set conversion clock Fosc/32,  bit 0 used to turn system ADC on
// bit 1 not used and bit 2 indicates when conversion complete (will be read)
// Read channel 0 (1000 0001)
// Read channel 1 (1000 1001)
// Read channel 2 (1001 0001)
// Read channel 3 (1001 1001)
// Read channel 4 (1010 0001)
#define    EdgeLeft      0b10000001    // Pin RA0-AN0 analog input EdgeLeft (left line sensor)
#define    EdgeCntLeft   0b10001001    // Pin RA1-AN1 analog input EdgeCntLeft (center left line sensor)
#define    EdgeCenter    0b10010001    // Pin RA2-AN2 analog input EdgeCenter (center left line sensor)
#define    EdgeCntRight  0b10011001    // Pin RA3-AN3 analog input EdgeCntRight (center right line sensor)
                   					   // Pin RA4 No connection
#define    EdgeRight     0b10100001    // Pin RA5-AN4 analog input EdgeRight (right line sensor)
                                       // note PortA is only 6 bits!

// Define logic to make the program easier to understand
#define yes       0b1        
#define no        0b0        
#define on        0b1
#define off       0b0
#define ledoff    0b1        // Logic for LEDs is reversed, PIC brd is designed to sink current to LEDs
#define ledon     0b0        // rather than source it. Logic "0" = on, "1" = off.


// Analog to Digital Conversion setup
#define ACDCON1setup    0b00000010

  // ADCON1 bits
// ADFM     bit 7;
// note ADCS2 is bit 6 in datasheet is not defined in pic1687x.h from HI-TECH!
// not used bit 5
// not used bit 4
// PCFG3    bit 3;
// PCFG2    bit 2;
// PCFG1    bit 1;
// PCFG0    bit 0;



